@@ -31,7 +31,7 @@ our %special_type = (
 	# Some of the type are not defined now!
 	boolean => "bool ",
 	int => "int32_t ",
-	"unsigned long" => "dom_ulong ",
+	"unsigned long" => "uint32_t ",
 	DOMString => "dom_string *",
 	List => "list *",
 	Collection => "list *",
@@ -66,8 +66,6 @@ our %special_prefix = (
 	HTMLTableSectionElement => "dom_html_table_section_element",
 	HTMLIsIndexElement => "dom_html_isindex_element",
         HTMLIFrameElement => "dom_html_iframe_element",
-        HTMLOListElement => "dom_html_olist_element",
-        HTMLDListElement => "dom_html_dlist_element",
 	caption => "dom_html_table_caption_element *",
 	section => "dom_html_table_section_element *",
 	createCaption => "dom_html_element *",
@@ -85,9 +83,8 @@ our %unref_prefix = (
 	DOMString => "dom_string",
 	NamedNodeMap => "dom_namednodemap",
 	NodeList => "dom_nodelist",
-	HTMLCollection => "dom_html_collection",
-	HTMLOptionsCollection => "dom_html_options_collection",
-	HTMLDocument => "dom_html_document",
+        HTMLCollection => "dom_html_collection",
+        HTMLDocument => "dom_html_document",
 );
 
 our %special_method = (
@@ -102,7 +99,6 @@ our %no_unref = (
 	"boolean" => 1,
 	"int" => 1,
 	"unsigned int" => 1,
-	"unsigned long" => 1,
 	"List" => 1,
 	"Collection" => 1,
 );
@@ -180,7 +176,6 @@ sub new {
 			# The list for UNREF
 			unref => [],
 			string_unref => [],
-                        block_unrefs => ["!!!"],
 			# The indent of current statement
 			indent => "",
 			# The variables for List/Collection
@@ -1252,9 +1247,7 @@ sub generate_control_statement {
 		}
 
 		case "for-each" {
-                        # Push a block onto the cleanups
-                        push(@{$self->{"block_unrefs"}}, "b");
-                        # Detect what is the collection type, if it is "string", we
+			# Detect what is the collection type, if it is "string", we
 			# should also do some conversion work
 			my $coll = $ats->{"collection"};
 			# The default member type is dom_node
@@ -1310,8 +1303,6 @@ sub generate_control_statement {
 				print "unsigned int iterator$iterator_index = 0;";
 				print "foreach_initialise_domnodelist($coll, \&iterator$iterator_index);\n";
 				print "while(get_next_domnodelist($coll, \&iterator$iterator_index, \&$member)) {\n";
-                                $self->addto_cleanup($member);
-                                push(@{$self->{'block_unrefs'}}, $member);
 			}
 
 			if ($self->{"var"}->{$coll} eq "NamedNodeMap") {
@@ -1319,8 +1310,6 @@ sub generate_control_statement {
 				print "unsigned int iterator$iterator_index = 0;";
 				print "foreach_initialise_domnamednodemap($coll, \&iterator$iterator_index);\n";
 				print "while(get_next_domnamednodemap($coll, \&iterator$iterator_index, \&$member)) {\n";
-                                $self->addto_cleanup($member);
-                                push(@{$self->{'block_unrefs'}}, $member);
 			}
 
 			if ($self->{"var"}->{$coll} eq "HTMLCollection") {
@@ -1328,8 +1317,6 @@ sub generate_control_statement {
 				print "unsigned int iterator$iterator_index = 0;";
 				print "foreach_initialise_domhtmlcollection($coll, \&iterator$iterator_index);\n";
 				print "while(get_next_domhtmlcollection($coll, \&iterator$iterator_index, \&$member)) {\n";
-                                $self->addto_cleanup($member);
-                                push(@{$self->{'block_unrefs'}}, $member);
 			}
 		}
 	}
@@ -1348,20 +1335,12 @@ sub complete_control_statement {
 		case [qw(if while for-each)] {
 			# Firstly, we should cleanup the dom_string in this block
 			$self->cleanup_block_domstring();
-                        $self->pop_block_unrefs() if ($name eq 'for-each');
+
 			print "}\n";
 		}
 	}
 }
 
-sub pop_block_unrefs {
-   my ($self) = @_;
-   while ((my $var = pop(@{$self->{'block_unrefs'}})) ne 'b') {
-      die "OMG!" if ($var eq '!!!');
-      print("if ($var != NULL) {\n    dom_node_unref($var);\n    $var = NULL;\n}\n");
-   }
-}
-
 
 ###############################################################################
 #
@@ -1578,12 +1557,6 @@ sub end_half_assertion {
 ### Enclose an unsed function
 ##############################################################################################
 
-sub cleanup_lists {
-   my ($self, $indent) = @_;
-   foreach my $list (keys %{$self->{list_map}}) {
-      print "${indent}if ($list != NULL)\n${indent}\tlist_destroy($list);\n" if ($list ne '');
-   }
-}
 
 sub cleanup_domvar {
 	my ($self, $indent) = @_;
@@ -1603,7 +1576,6 @@ sub cleanup {
 	my $self = shift;
 
 	print "\n\n";
-        $self->cleanup_lists("\t");
 	$self->cleanup_domstring("\t");
 	$self->cleanup_domvar("\t");
         print "\n\tprintf(\"PASS\");\n";
@@ -1620,7 +1592,7 @@ sub addto_cleanup {
 		if (exists $unref_prefix{$type}) {
 			$prefix = $unref_prefix{$type};
 		}
-		push(@{$self->{unref}}, "if (".$var." != NULL) { ".$prefix."_unref(".$var."); ".$var." = NULL; }\n");
+		push(@{$self->{unref}}, $prefix."_unref(".$var.");\n");
 	}
 }
 
